#include <iostream>
#include <vector>

using namespace std;

struct SegTree {
    int sz;
    vector<int> val, mod;

    SegTree(int sz_) : sz(sz_) {
        val.resize(4 * sz);
        mod.resize(4 * sz);
    }

    void push(int u) {
        val[2 * u + 1] += mod[u];
        val[2 * u + 2] += mod[u];
        mod[2 * u + 1] += mod[u];
        mod[2 * u + 2] += mod[u];
        mod[u] = 0;
    }

    void add_(int u, int L, int R, int l, int r, int v) {
        if (L >= r || l >= R) {
            return;
        }
        if (l <= L && R <= r) {
            mod[u] += v;
            val[u] += v;
            return;
        }
        int M = (L + R) / 2;
        push(u);
        add_(2 * u + 1, L, M, l, r, v);
        add_(2 * u + 2, M, R, l, r, v);
        val[u] = min(val[2 * u + 1], val[2 * u + 2]);
    }

    void add(int l, int r, int v) {
        add_(0, 0, sz, l, r, v);
    }

    int get() {
        return val[0];
    }
};

int main() {
#ifdef DEBUG
    freopen("input", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);

    int n, m, q;
    cin >> n >> m >> q;
    vector<int> cost(n + 1);
    vector<vector<int>> col(n, vector<int> (m));
    int cur = 0;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            col[i][j] = ((i + j) & 1);
            cur += col[i][j];
        }
    }

    SegTree st(n + 1);

    cost[0] = cur;
    st.add(0, 1, cur);
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (col[i][j] == 1) {
                cur--;
            } else {
                cur++;
            }
        }
        cost[i + 1] = cur;
        st.add(i + 1, i + 2, cur);
    }

    while (q--) {
        int x, y;
        cin >> x >> y;
        x--;
        y--;

        int v = col[x][y] == 0 ? 1 : -1;

        st.add(0, x + 1, v);
        st.add(x + 1, n + 1, -v);

        col[x][y] = 1 - col[x][y];

        cout << st.get() << "\n";
    }

    return 0;
}